==> evilvte_0.5.0-1.debian.tar.xz: debian/config.h <==
#define BACKGROUND_IMAGE       ".config/evilvte/background.png"
#define BACKSPACE_KEY          DELETE
#define BUTTON_ORDER_BY_RCFILE TRUE
#define CLOSE_DIALOG           TRUE
#define COMMAND_AT_ROOT_WINDOW TRUE
#define COMMAND_DOCK_MODE      TRUE
#define COMMAND_EXEC_PROGRAM   TRUE
#define COMMAND_FULLSCREEN     TRUE
#define COMMAND_FONT           TRUE
#define COMMAND_GEOMETRY       TRUE
#define COMMAND_LOGIN_SHELL    TRUE
#define COMMAND_SET_TITLE      TRUE
#define COMMAND_SHOW_HELP      TRUE
#define COMMAND_SHOW_OPTIONS   TRUE
#define COMMAND_SHOW_VERSION   TRUE
#define COMMAND_TAB_NUMBERS    TRUE
#define MOUSE_CTRL_SATURATION  TRUE
#define SCROLL_LINES           1000
#define SCROLLBAR              RIGHT
#define SHOW_WINDOW_BORDER     FALSE
#define SHOW_WINDOW_ICON       TRUE
#define WORD_CHARS             "-A-Za-z0-9_$.+!*(),;:@&=?/~#%"
#define MENU                   TRUE
#define MENU_ENCODING_LIST     "Default Encoding", "UTF-8", "EUC-JP", "EUC-KR", "GBK", "BIG-5"
#define MENU_MATCH_STRING_EXEC "x-www-browser"
#define MENU_CUSTOM            "Copy", "Paste", "Select all", "Separator", "Add tab", "Remove tab", "Edit label", "Separator", "Toggle background", "Toggle tabbar", "Toggle scrollbar", "Toggle anti-alias", "Toggle window decorated", "Separator", "Select font", "Reset terminal", "Adjust saturation", "Background tint", "Submenu encoding list", "Submenu input method"
#define TAB                    TRUE
#define TAB_BORDER             0
#define TAB_EXPANDED_WIDTH     TRUE
#define TAB_NEW_PATH_EQUAL_OLD TRUE
#define TAB_SHOW_INFO_AT_TITLE TRUE
#define TABBAR_AUTOHIDE        TRUE
#define TABBAR_SCROLLABLE      TRUE
#define HOTKEY                 TRUE
#define HOTKEY_COPY            CTRL GDK_C
#define HOTKEY_PASTE           CTRL GDK_V
#define HOTKEY_TAB_ADD         CTRL GDK_T
#define HOTKEY_TAB_REMOVE      CTRL GDK_W
#define HOTKEY_TAB_PREVIOUS    CTRL GDK_Page_Up
#define HOTKEY_TAB_NEXT        CTRL GDK_Page_Down
#define TOGGLE_BG_ORDER        "Image", "Transparent", "No background"

==> evilvte_0.5.1-1.debian.tar.xz: debian/config.h <==
#define BACKGROUND_IMAGE       ".config/evilvte/background.png"
#define BACKSPACE_KEY          DELETE
#define BUTTON_ORDER_BY_RCFILE TRUE
#define CLOSE_DIALOG           TRUE
#define COMMAND_AT_ROOT_WINDOW TRUE
#define COMMAND_DOCK_MODE      TRUE
#define COMMAND_EXEC_PROGRAM   TRUE
#define COMMAND_FULLSCREEN     TRUE
#define COMMAND_FONT           TRUE
#define COMMAND_GEOMETRY       TRUE
#define COMMAND_LOGIN_SHELL    TRUE
#define COMMAND_SET_TITLE      TRUE
#define COMMAND_SHOW_HELP      TRUE
#define COMMAND_SHOW_OPTIONS   TRUE
#define COMMAND_SHOW_VERSION   TRUE
#define COMMAND_TAB_NUMBERS    TRUE
#define MOUSE_CTRL_SATURATION  TRUE
#define SCROLL_LINES           1000
#define SCROLLBAR              RIGHT
#define SHOW_WINDOW_BORDER     FALSE
#define SHOW_WINDOW_ICON       TRUE
#define WORD_CHARS             "-A-Za-z0-9_$.+!*(),;:@&=?/~#%"
#define MENU                   TRUE
#define MENU_ENCODING_LIST     "Default Encoding", "UTF-8", "EUC-JP", "EUC-KR", "GBK", "BIG-5"
#define MENU_MATCH_STRING_EXEC "x-www-browser"
#define MENU_CUSTOM            "Copy", "Paste", "Select all", "Separator", "Add tab", "Remove tab", "Edit label", "Separator", "Toggle background", "Toggle tabbar", "Toggle scrollbar", "Toggle anti-alias", "Toggle window decorated", "Separator", "Select font", "Reset terminal", "Adjust saturation", "Background tint", "Submenu encoding list", "Submenu input method"
#define TAB                    TRUE
#define TAB_BORDER             0
#define TAB_EXPANDED_WIDTH     TRUE
#define TAB_NEW_PATH_EQUAL_OLD TRUE
#define TAB_SHOW_INFO_AT_TITLE TRUE
#define TABBAR_AUTOHIDE        TRUE
#define TABBAR_SCROLLABLE      TRUE
#define HOTKEY                 TRUE
#define HOTKEY_COPY            CTRL(GDK_C)
#define HOTKEY_PASTE           CTRL(GDK_V)
#define HOTKEY_TAB_ADD         CTRL(GDK_T)
#define HOTKEY_TAB_REMOVE      CTRL(GDK_W)
#define HOTKEY_TAB_PREVIOUS    CTRL(GDK_Page_Up)
#define HOTKEY_TAB_NEXT        CTRL(GDK_Page_Down)
#define TOGGLE_BG_ORDER        "Image", "Transparent", "No background"
